@@ -34,7 +34,7 @@ sub get {
 
   use Net::GPSD::Point;
   my $point=Net::GPSD::Point->new();
-  $point->tag(ref($self));
+  $point->tag("FAKE");
   $point->lat($self->lat);
   $point->lon($self->lon);
   $point->speed(0);
@@ -115,8 +115,6 @@ Returns a list of Net::GPSD::Satellite objects
 
 =head1 KNOWN LIMITATIONS
 
-Only knows l and w commands
-
 =head1 BUGS
 
 =head1 EXAMPLES
